<?php

App::uses('EvContactFormAppController', 'EvContactForm.Controller');

class ContactFormResponsesController extends EvContactFormAppController
{

	public $uses = "EvContactForm.ContactFormResponse";


	public $adminActions = array(
		'admin_index',
		'admin_actioned',
		'admin_view',
		'admin_delete',
	);


	/**
	 * index action
	 */
	public function _adminIndexActions() {

		return array(
			'Admin View',
			'Delete'
		);

	}

	/**
	 * remove the filter
	 */
	public function _adminFilterFields() {
		return array();
	}

	/**
	 * define the columns to show on the listing
	 */
	public function _adminIndexColumns() {

		return array(
			'ContactForm.name' => array(
				'label' => 'Contact Form',
				'type' => 'string'
			),	
			'ContactFormResponse.name' => array(
				'label' => 'Name',
				'type' => 'string'
			),
			'ContactFormResponse.created' => array(
				'label' => 'Submitted',
				'type' => 'datetime_nice'
			),
			'ContactFormResponse.actioned' => array(
				'label' => 'Actioned',
				'type' => 'datetime_nice'
			)
		);
	}

	/**
	 * Pagination settings for admin_index
	 *
	 * Override in your own controller to customise
	 */
	public function _adminIndexPaginate() {

		$conditions = $this->_processFilter();

		$paginate = array(
			//'fields'=>join(",", array_keys($this->_adminIndexColumns())),
			'conditions'=>$conditions,
			'contain' => array('ContactForm'),
			'order' => 'ContactFormResponse.created DESC'
		);

		return $paginate;
	}

	/**
	 * remove the add button
	 */
	public function _adminIndexToolbar() {
		return array();
	}

	/**
	 * Defines the buttons in the toolbar displayed on an admin_form
	 *
	 * Override in your controller to customise
	 */
	public function _adminFormToolbar($id = NULL) {

		$Model = $this->{$this->modelClass}->alias;

		$toolbar = array();
		if(isset($this->request->data[$Model]['id']) && is_null($this->request->data[$Model]['actioned']))
		{
			$toolbar = array(
				'Mark as Actioned' => array(
					'url' => array(
						'controller' => 'contact_form_responses',
						'plugin' => 'ev_contact_form',
						'action' => 'actioned',
						$this->request->data[$Model]['id']
					),
					'class' => 'toolbar__btn--tick'
				)
			);
		}

		$toolbar['Delete'] = array(
			'url' => array('action' => 'delete', $this->request->data[$Model]['id']),
			'class' => 'toolbar__btn--delete'
		);

		return $toolbar;
	}

	/**
	 * admin view
	 *
	 * actually just a view with an "mark as actioned button"
	 */
	public function admin_view($id = null) 
	{
		$Model = $this->{$this->modelClass};

		$config = Configure::read('EvContactForm');
		$this->request->data = $data = $Model->readForView($id);

		if (!$this->request->data) {
			throw new NotFoundException();
		}

		$form = $Model->ContactForm->find('first', array('conditions' => array(
				'ContactForm.id' => $this->request->data['ContactFormResponse']['contact_form_id']
		)));


		$this->set('contact_form_fields', $config[$form['ContactForm']['form_data']]['fields']);
		$this->set('data', $data);
		$this->set('toolbar', $this->_adminFormToolbar());
		$this->render('EvContactForm.admin_view');
	}

	/**
	 * mark the message as actioned
	 *
	 * @param 	int 	contact form id
	 */
	public function admin_actioned($id)
	{

		$data = array(
			'ContactFormResponse' => array(
				'actioned' => date('Y-m-d H:i:s')
			)
		);
		$this->ContactFormResponse->id = $id;

		if ($this->ContactFormResponse->save($data)) {

			$this->Session->setFlash(array(
				'title' => "Message Updated",
				'description' => 'Message has been marked as actioned'
			), 'flash_success');

			$this->redirect(array(
				'action' => 'index'
			));

		} else {

			$this->Session->setFlash(array(
				'title' => 'Save Failed',
				'description' => 'Failed to mark the message as actioned'
			), 'flash_fail');

			$this->redirect(array(
				'action' => 'edit',
				$id
			));
		}
	}
}